@@ -1,3 +1,5 @@
+from enum import Enum
+
 from fastapi import APIRouter, Request, Form
 from fastapi.responses import HTMLResponse
 
@@ -11,6 +13,11 @@ from dhtc_server.enums.SearchMode import SearchMode
 router = APIRouter()
 
 
+class Operation(Enum):
+    ADD = "add"
+    DELETE = "delete"
+
+
 @router.get("/watches", response_class=HTMLResponse)
 async def watches(request: Request):
     return make_response(request, {
@@ -21,18 +28,27 @@ async def watches(request: Request):
 
 @router.post("/watches", response_class=HTMLResponse)
 async def watches(request: Request,
-                  type: SearchType = Form(),
-                  mode: SearchMode = Form(),
-                  text: str = Form()):
-    watch = Watch(
-        type=type,
-        mode=mode,
-        text=text
-    )
+                  type: SearchType = Form(SearchType.TITLE),
+                  mode: SearchMode = Form(SearchMode.CONTAINS),
+                  text: str = Form(""),
+                  op: Operation = Form(Operation.ADD),
+                  id: str = Form("")):
 
-    await watch.save()
+    print(text, mode, type, op, id)
+
+    result = False
+
+    match op:
+        case Operation.ADD:
+            if text != "":
+                await Watch(type=type, mode=mode, text=text).save()
+                result = True
+        case Operation.DELETE:
+            if id != "":
+                await Watch.delete(id=id)
+                result = True
 
     return make_response(request, {
-        "query": "",
+        "result": result,
         "results": await Watch.find_all().to_list()
     }, "watches.html")
