@@ -1,7 +1,3 @@
-function getBaseUrl() {
-    return window.location.origin;
-}
-
 function getTorrentCountUrl() {
     return getBaseUrl() + "/api/torrent/count";
 }
@@ -95,10 +91,11 @@ function TorrentCategoryChart(container, label, height = 32) {
                     tension: 0.42,
                     backgroundColor: [
                         'rgb(255,0,0)',
-                        'rgb(255,128,0)',
-                        'rgb(167,255,0)',
+                        'rgb(255,0,142)',
+                        'rgb(0,72,255)',
+                        'rgb(255,208,0)',
                         'rgb(0,255,154)',
-                        'rgb(0,102,255)',
+                        'rgb(32,255,0)',
                         'rgb(155,0,255)',
                     ]
                 }
